@@ -15,7 +15,7 @@ if(is.numeric(level) == FALSE) {
 	}
 
 ## Make sure that the data exist for the dates given ##
-if(reanalysis2 == TRUE && as.numeric(format(strptime(dt, "%Y-%m-%d %H:%M:%S"), "%Y")) < 1979) {stop("The datetime specified is out of range for the Reanalysis 2 dataset.")}
+if(reanalysis2 == TRUE && any(as.numeric(format(strptime(dt, "%Y-%m-%d %H:%M:%S"), "%Y")) < 1979)) {stop("A datetime specified is out of range for the Reanalysis 2 dataset.")}
 if(any(as.numeric(format(strptime(dt, "%Y-%m-%d %H:%M:%S"), "%Y")) < 1948)) {stop("The datetime specified is out of range.")}
 
 ## Make sure that keep.unpacking.info == FALSE when it should be ##
